==> signmaker_ui-1.0.0.tar.gz: signmaker_ui/src/Controller/SignmakerController.php <==
<?php

namespace Drupal\signmaker_ui\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Render\HtmlResponse;
use SFEnvironment\Signmaker\Signmaker;
use Symfony\Component\HttpFoundation\BinaryFileResponse;
use Symfony\Component\HttpFoundation\Request;

class SignmakerController extends ControllerBase {
  public function process(Request $request) {

    if ($request->isMethod('POST')) {
      $content = json_decode($request->getContent());
      $html = $content->html;
      /** @var \Drupal\Core\File\FileSystemInterface $file_system */
      $file_system = \Drupal::service('file_system');
      $pdf_contents = Signmaker::generate($html, 'output', ['/files']);
      $uri = $file_system->tempnam('temporary://', 'signmaker_');
      $path = $file_system->saveData($pdf_contents, $uri);
      $response = new BinaryFileResponse($path);
    } else {
      try {
        $markup = Signmaker::handle();
        $response = new HtmlResponse($markup, HtmlResponse::HTTP_OK, [
          'Content-Type' => 'text/html; charset=UTF-8',
        ]);
        $response->addCacheableDependency($request);
      } catch (\Exception $e) {
        \Drupal::logger('signmaker_ui')->error($e->getMessage());
        $response = ['#markup' => 'An error occurred while processing your request.'];
      }
    }


    return $response;
  }

  public function asset($path, $filename) {
    $uri = "../vendor/sf/signmaker/assets/{$path}/{$filename}";
    $response = new BinaryFileResponse($uri);
    return $response;
  }
}

==> signmaker_ui-1.0.1.tar.gz: signmaker_ui/src/Controller/SignmakerController.php <==
<?php

namespace Drupal\signmaker_ui\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Render\HtmlResponse;
use SFEnvironment\Signmaker\Signmaker;
use Symfony\Component\HttpFoundation\BinaryFileResponse;
use Symfony\Component\HttpFoundation\Request;

class SignmakerController extends ControllerBase {
  public function process(Request $request) {

    if ($request->isMethod('POST')) {
      $content = json_decode($request->getContent());
      $html = $content->html;
      /** @var \Drupal\Core\File\FileSystemInterface $file_system */
      $file_system = \Drupal::service('file_system');
      $pdf_contents = Signmaker::generate($html, 'output', ['/files']);
      $uri = $file_system->tempnam('temporary://', 'signmaker_');
      $path = $file_system->saveData($pdf_contents, $uri);
      $response = new BinaryFileResponse($path);
    } else {
      try {
        $markup = Signmaker::handle();
        $response = new HtmlResponse($markup, HtmlResponse::HTTP_OK, [
          'Content-Type' => 'text/html; charset=UTF-8',
        ]);
        $response->addCacheableDependency($request);
      } catch (\Exception $e) {
        \Drupal::logger('signmaker_ui')->error($e->getMessage());
        $response = ['#markup' => 'An error occurred while processing your request.'];
      }
    }


    return $response;
  }

  public function asset($path, $filename) {
    $uri = "../vendor/sfenvironment/signmaker/assets/{$path}/{$filename}";
    $response = new BinaryFileResponse($uri);
    return $response;
  }
}
